package api

import (
	"context"
	"hk/pkg/util/strUtil"

	"hk/service/api/internal/svc"
	"hk/service/api/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type GoodsDetailsLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewGoodsDetailsLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GoodsDetailsLogic {
	return &GoodsDetailsLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *GoodsDetailsLogic) GoodsDetails(req *types.GoodsDetailsReq) (resp *types.GoodsDetailsResp, err error) {
	if req.Id <= 0 {
		return nil, nil
	}
	goods, err := l.svcCtx.GoodsInfoModel.FindOne(l.ctx, req.Id)
	if err != nil || goods == nil || goods.Status == "0" {
		return nil, err
	}
	resp = &types.GoodsDetailsResp{
		Data: types.GoodsItem{
			Id:         goods.Id,
			Name:       goods.Name,
			MainPic:    goods.MainPic,
			DisableAge: goods.DisableAge,
			UniFlow:    goods.UniFlow,
			DirFlow:    goods.DirFlow,
			TalkTime:   goods.TalkTime,
			Remarks:    strUtil.ValidString(goods.Remarks),
		},
	}
	return resp, nil
}
