package api

import (
	"context"
	"hk/pkg/util/strUtil"

	"hk/service/api/internal/svc"
	"hk/service/api/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type GoodsListLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewGoodsListLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GoodsListLogic {
	return &GoodsListLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *GoodsListLogic) GoodsList(req *types.GoodsListReq) (resp *types.GoodsListResp, err error) {
	goods, err := l.svcCtx.GoodsInfoModel.GetGoodsIndex(l.ctx, req.Type)
	if err != nil || len(goods) == 0 {
		return nil, err
	}
	var goodsList []types.GoodsItem
	for _, item := range goods {
		good := types.GoodsItem{
			Id:         item.Id,
			Name:       item.Name,
			MainPic:    item.MainPic,
			DisableAge: item.DisableAge,
			UniFlow:    item.UniFlow,
			DirFlow:    item.DirFlow,
			TalkTime:   item.TalkTime,
			Remarks:    strUtil.ValidString(item.Remarks),
		}
		goodsList = append(goodsList, good)
	}
	resp = &types.GoodsListResp{
		Data: goodsList,
	}
	return resp, nil
}
