package api

import (
	"context"
	"hk/pkg/util/tiktok"

	"hk/service/api/internal/svc"
	"hk/service/api/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type TiktokInfoLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewTiktokInfoLogic(ctx context.Context, svcCtx *svc.ServiceContext) *TiktokInfoLogic {
	return &TiktokInfoLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *TiktokInfoLogic) TiktokInfo(req *types.TiktokReq) (resp *types.TiktokResp, err error) {
	if len(req.VideoUrl) <= 0 {
		return nil, nil
	}
	tiktokInfo, err := tiktok.GetTiktokVideoInfo(req.VideoUrl)
	if err != nil || tiktokInfo == nil {
		return nil, nil
	}
	resp = &types.TiktokResp{
		AuthorID:          tiktokInfo.AuthorID,
		AuthorAvatar:      tiktokInfo.AuthorAvatar,
		AuthorUniqueID:    tiktokInfo.AuthorUniqueID,
		AuthorNickname:    tiktokInfo.AuthorNickname,
		VideoID:           tiktokInfo.VideoID,
		VideoTitle:        tiktokInfo.VideoTitle,
		OriginCover:       tiktokInfo.OriginCover,
		DynamicCover:      tiktokInfo.DynamicCover,
		DestinationURL:    tiktokInfo.DestinationURL,
		WatermarkVideoURL: tiktokInfo.WatermarkVideoURL,
		MusicURL:          tiktokInfo.MusicURL,
		OriginalURL:       tiktokInfo.OriginalURL,
		DownloaderURL:     tiktokInfo.DownloaderURL,
		CreateTime:        tiktokInfo.CreateTime,
		Result:            true,
	}
	return resp, nil
}
